@@ -628,7 +628,7 @@ void network_process_file(char *filename,
 	long msgend = (-1L);
 	long msgcur = 0L;
 	int ch;
-
+	int nMessages = 0;
 
 	fp = fopen(filename, "rb");
 	if (fp == NULL) {
@@ -657,6 +657,7 @@ void network_process_file(char *filename,
 		}
 
 		++msgcur;
+		nMessages ++;
 	}
 
 	msgend = msgcur - 1;
@@ -667,8 +668,15 @@ void network_process_file(char *filename,
 					working_ignetcfg,
 					the_netmap,
 					netmap_changed);
+		nMessages ++;
 	}
 
+	if (nMessages > 0)
+		QN_syslog(LOG_INFO,
+			  "network: processed %d messages in %s\n",
+			  nMessages,
+			  filename);
+
 	fclose(fp);
 	unlink(filename);
 }
@@ -717,7 +725,7 @@ void network_do_spoolin(HashList *working_ignetcfg, HashList *the_netmap, int *n
 	       (filedir_entry != NULL))
 	{
 #ifdef _DIRENT_HAVE_D_NAMLEN
-		d_namelen = filedir_entry->d_namelen;
+		d_namelen = filedir_entry->d_namlen;
 
 #else
 		d_namelen = strlen(filedir_entry->d_name);
@@ -821,7 +829,7 @@ void network_consolidate_spoolout(HashList *working_ignetcfg, HashList *the_netm
 	       (filedir_entry != NULL))
 	{
 #ifdef _DIRENT_HAVE_D_NAMLEN
-		d_namelen = filedir_entry->d_namelen;
+		d_namelen = filedir_entry->d_namlen;
 
 #else
 		d_namelen = strlen(filedir_entry->d_name);
