@@ -20,15 +20,15 @@
  * The VRFY and EXPN commands have been removed from this implementation
  * because nobody uses these commands anymore, except for spammers.
  *
- * Copyright (c) 1998-2012 by the citadel.org team
+ * Copyright (c) 1998-2013 by the citadel.org team
  *
- *  This program is open source software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 3.
+ * This program is open source software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3.
  *  
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  */
 
 #include "sysdep.h"
@@ -147,6 +147,8 @@ void smtp_greeting(int is_msa)
 	sSMTP->from = NewStrBufPlain(NULL, SIZ);
 	sSMTP->recipients = NewStrBufPlain(NULL, SIZ);
 	sSMTP->OneRcpt = NewStrBufPlain(NULL, SIZ);
+	sSMTP->preferred_sender_email = NULL;
+	sSMTP->preferred_sender_name = NULL;
 
 	/* If this config option is set, reject connections from problem
 	 * addresses immediately instead of after they execute a RCPT
@@ -336,6 +338,7 @@ void smtp_webcit_preferences_hack_backend(long msgnum, void *userdata) {
 void smtp_webcit_preferences_hack(void) {
 	char config_roomname[ROOMNAMELEN];
 	char *webcit_conf = NULL;
+	citsmtp *sSMTP = SMTP;
 
 	snprintf(config_roomname, sizeof config_roomname, "%010ld.%s", CC->user.usernum, USERCONFIGROOM);
 	if (CtdlGetRoom(&CC->room, config_roomname) != 0) {
@@ -352,10 +355,24 @@ void smtp_webcit_preferences_hack(void) {
 		return;
 	}
 
-	/* FIXME : now do something with this data */
+	/* Parse the webcit configuration and attempt to do something useful with it */
+	char *str = webcit_conf;
+	char *saveptr = str;
+	char *this_line = NULL;
+	while (this_line = strtok_r(str, "\n", &saveptr), this_line != NULL) {
+		str = NULL;
+		if (!strncasecmp(this_line, "defaultfrom|", 12)) {
+			sSMTP->preferred_sender_email = NewStrBufPlain(&this_line[12], -1);
+		}
+		if (!strncasecmp(this_line, "defaultname|", 12)) {
+			sSMTP->preferred_sender_name = NewStrBufPlain(&this_line[12], -1);
+		}
+		if ((!strncasecmp(this_line, "defaultname|", 12)) && (sSMTP->preferred_sender_name == NULL)) {
+			sSMTP->preferred_sender_name = NewStrBufPlain(&this_line[12], -1);
+		}
 
+	}
 	free(webcit_conf);
-	abort();
 }
 
 
@@ -444,7 +461,7 @@ void smtp_try_plain(long offset, long Flags)
 
 	if (result == login_ok) {
 		if (CtdlTryPassword(pass, len) == pass_ok) {
-////			smtp_webcit_preferences_hack();
+			smtp_webcit_preferences_hack();
 			smtp_auth_greeting(offset, Flags);
 			return;
 		}
@@ -602,7 +619,7 @@ void smtp_mail(long offset, long flags) {
 	 * address so we don't have to contend with the empty string causing
 	 * other code to fail when it's expecting something there.
 	 */
-	if (StrLength(sSMTP->from)) {
+	if (StrLength(sSMTP->from) == 0) {
 		StrBufPlain(sSMTP->from, HKEY("someone@example.com"));
 	}
 
@@ -843,14 +860,23 @@ void smtp_data(long offset, long flags)
 		if (msg->cm_fields['N'] != NULL) free(msg->cm_fields['N']);
 		if (msg->cm_fields['H'] != NULL) free(msg->cm_fields['H']);
 		if (msg->cm_fields['O'] != NULL) free(msg->cm_fields['O']);
-		msg->cm_fields['A'] = strdup(CCC->user.fullname);
 		msg->cm_fields['N'] = strdup(config.c_nodename);
 		msg->cm_fields['H'] = strdup(config.c_humannode);
         	msg->cm_fields['O'] = strdup(MAILROOM);
 
+		msg->cm_fields['A'] =
+			((sSMTP->preferred_sender_name != NULL)
+			? strdup(ChrPtr(sSMTP->preferred_sender_name)) 
+			: strdup(CCC->user.fullname)
+		);
+
 		if (!validemail) {
 			if (msg->cm_fields['F'] != NULL) free(msg->cm_fields['F']);
-			msg->cm_fields['F'] = strdup(CCC->cs_inet_email);
+			msg->cm_fields['F'] = 
+				((sSMTP->preferred_sender_email != NULL)
+				? strdup(ChrPtr(sSMTP->preferred_sender_email)) 
+				: strdup(CCC->cs_inet_email)
+			);
 		}
 	}
 
@@ -989,6 +1015,7 @@ void smtp_command_loop(void)
 
 	else if (sSMTP->command_state == smtp_plain) {
 		smtp_try_plain(0, 0);
+		return;
 	}
 
 	pchs = pch = ChrPtr(sSMTP->Cmd);
@@ -1056,6 +1083,8 @@ void smtp_cleanup_function(void)
 	FreeStrBuf(&sSMTP->from);
 	FreeStrBuf(&sSMTP->recipients);
 	FreeStrBuf(&sSMTP->OneRcpt);
+	FreeStrBuf(&sSMTP->preferred_sender_email);
+	FreeStrBuf(&sSMTP->preferred_sender_name);
 
 	free(sSMTP);
 }
