@@ -11,14 +11,6 @@
  */
 #define CHATLOG		"/dev/null"
 
-/* 
- * S_KEEPALIVE is a watchdog timer.  It is used to send "keep
- * alive" messages to the server to prevent the server from assuming the
- * client is dead and terminating the session.  30 seconds is the recommended
- * value; I can't think of any good reason to change it.
- */
-#define S_KEEPALIVE	30
-
 /*
  * Logging level to use if none is specified on the command line.
  * Note that this will suppress messages before they even get to syslog().
@@ -107,7 +99,9 @@
 /*
  * How long (in seconds) to retain message entries in the use table
  */
-#define USETABLE_RETAIN		604800L		/* 7 days */
+#define USETABLE_RETAIN			864000L		/* 10 days */
+#define USETABLE_ANTIEXPIRE     	345600l         /*  4 days */
+#define USETABLE_ANTIEXPIRE_HIRES	 86400l         /*  1 day */
 
 /*
  * The size of per-thread stacks.  If set too low, citserver will randomly crash.
